define(["exports", "core/pubsubhub", "deps/text!core/css/issues-notes.css", "core/utils", "deps/hyperhtml"], function (exports, _pubsubhub, _issuesNotes, _utils) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.name = undefined;
  exports.run = run;

  var _issuesNotes2 = _interopRequireDefault(_issuesNotes);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  var _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  const name = exports.name = "core/issues-notes";

  const MAX_GITHUB_REQUESTS = 60;

  function handleIssues(ins, ghIssues, conf) {
    const $ins = $(ins);
    const { issueBase, githubAPI } = conf;
    var hasDataNum = !!document.querySelector(".issue[data-number]"),
        issueNum = 0,
        $issueSummary = $("<div><h2>" + conf.l10n.issue_summary + "</h2><ul></ul></div>"),
        $issueList = $issueSummary.find("ul");
    if (githubAPI) {
      Array.from($ins).filter(({ dataset: { number: value } }) => value !== undefined && ghIssues.get(Number(value)).state === "closed").forEach(issue => {
        const {
          dataset: { number }
        } = issue;
        const msg = `Github issue ${number} was closed on GitHub, so removing from spec`;
        (0, _pubsubhub.pub)("warn", msg);
        issue.remove();
      });
    }
    $ins.filter((i, issue) => issue.parentNode).each(function (i, inno) {
      var $inno = $(inno),
          isIssue = $inno.hasClass("issue"),
          isWarning = $inno.hasClass("warning"),
          isEdNote = $inno.hasClass("ednote"),
          isFeatureAtRisk = $inno.hasClass("atrisk"),
          isInline = $inno[0].localName === "span",
          dataNum = $inno.attr("data-number"),
          report = {
        inline: isInline
      };
      report.type = isIssue ? "issue" : isWarning ? "warning" : isEdNote ? "ednote" : "note";
      if (isIssue && !isInline && !hasDataNum) {
        issueNum++;
        report.number = issueNum;
      } else if (dataNum) {
        report.number = dataNum;
      }
      // wrap
      if (!isInline) {
        var $div = $("<div class='" + report.type + (isFeatureAtRisk ? " atrisk" : "") + "'></div>"),
            $tit = $("<div role='heading' class='" + report.type + "-title'><span></span></div>"),
            text = isIssue ? isFeatureAtRisk ? conf.l10n.feature_at_risk : conf.l10n.issue : isWarning ? conf.l10n.warning : isEdNote ? conf.l10n.editors_note : conf.l10n.note,
            ghIssue;
        if (inno.id) {
          $div[0].id = inno.id;
          inno.removeAttribute("id");
        } else {
          $div.makeID("issue-container", report.number ? `number-${report.number}` : "");
        }
        $tit.makeID("h", report.type);
        report.title = $inno.attr("title");
        if (isIssue) {
          if (hasDataNum) {
            if (dataNum) {
              text += " " + dataNum;
              // Set issueBase to cause issue to be linked to the external issue tracker
              if (!isFeatureAtRisk && issueBase) {
                $tit.find("span").wrap($("<a href='" + issueBase + dataNum + "'/>"));
              } else if (isFeatureAtRisk && conf.atRiskBase) {
                $tit.find("span").wrap($("<a href='" + conf.atRiskBase + dataNum + "'/>"));
              }
              ghIssue = ghIssues.get(Number(dataNum));
              if (ghIssue && !report.title) {
                report.title = ghIssue.title;
              }
            }
          } else {
            text += " " + issueNum;
          }
          if (report.number !== undefined) {
            // Add entry to #issue-summary.
            var $li = $("<li><a></a></li>");
            var $a = $li.find("a");
            $a.attr("href", "#" + $div[0].id).text(conf.l10n.issue + " " + report.number);
            if (report.title) {
              $li.append($("<span style='text-transform: none'>: " + report.title + "</span>"));
            }
            $issueList.append($li);
          }
        }
        $tit.find("span").text(text);
        if (ghIssue && report.title && githubAPI) {
          const labelsGroup = Array.from(ghIssue.labels).map(label => {
            const issuesURL = new URL("issues/", conf.github.repoURL + "/");
            issuesURL.searchParams.set("q", `is:issue is:open label:"${label.name}"`);
            return _extends({}, label, {
              href: issuesURL.href
            });
          }).map(createLabel).reduce((frag, labelElem) => {
            frag.appendChild(labelElem);
            return frag;
          }, document.createDocumentFragment());
          $tit.append($("<span style='text-transform: none'>: " + report.title + "</span>").append(labelsGroup));
          $inno.removeAttr("title");
        } else if (report.title) {
          $tit.append($("<span style='text-transform: none'>: " + report.title + "</span>"));
          $inno.removeAttr("title");
        }
        $tit.addClass("marker");
        $div.append($tit);
        $inno.replaceWith($div);
        var body = $inno.removeClass(report.type).removeAttr("data-number");
        if (ghIssue && !body.text().trim()) {
          body = ghIssue.body_html;
        }
        $div.append(body);
        const level = $tit.parents("section").length + 2;
        $tit.attr("aria-level", level);
      }
      (0, _pubsubhub.pub)(report.type, report);
    });
    if ($(".issue").length) {
      if ($("#issue-summary")) $("#issue-summary").append($issueSummary.contents());
    } else if ($("#issue-summary").length) {
      (0, _pubsubhub.pub)("warn", "Using issue summary (#issue-summary) but no issues found.");
      $("#issue-summary").remove();
    }
  }

  async function fetchAndStoreGithubIssues(conf) {
    const { githubAPI, githubUser, githubToken } = conf;
    const specIssues = document.querySelectorAll(".issue[data-number]");
    if (specIssues.length > MAX_GITHUB_REQUESTS) {
      const msg = `Your spec contains ${specIssues.length} Github issues, ` + `but GitHub only allows ${MAX_GITHUB_REQUESTS} requests. Some issues might not show up.`;
      (0, _pubsubhub.pub)("warning", msg);
    }
    const issuePromises = [...specIssues].map(elem => Number.parseInt(elem.dataset.number, 10)).filter(issueNumber => issueNumber).map(async issueNumber => {
      const issueURL = `${githubAPI}/issues/${issueNumber}`;
      const headers = {
        // Get back HTML content instead of markdown
        // See: https://developer.github.com/v3/media/
        Accept: "application/vnd.github.v3.html+json"
      };
      if (githubUser && githubToken) {
        const credentials = btoa(`${githubUser}:${githubToken}`);
        const Authorization = `Basic ${credentials}`;
        Object.assign(headers, { Authorization });
      }
      const request = new Request(issueURL, {
        headers
      });
      const response = await (0, _utils.fetchAndCache)(request);
      return processResponse(response, issueNumber);
    });
    const issues = await Promise.all(issuePromises);
    return new Map(issues);
  }

  function isLight(rgb) {
    const red = rgb >> 16 & 0xff;
    const green = rgb >> 8 & 0xff;
    const blue = rgb >> 0 & 0xff;
    const illumination = 0.2126 * red + 0.7152 * green + 0.0722 * blue;
    return illumination > 140;
  }

  function createLabel(label) {
    const { color, href, name } = label;
    const rgb = parseInt(color, 16);
    const textColorClass = isNaN(rgb) || isLight(rgb) ? "light" : "dark";
    const cssClasses = `respec-gh-label respec-label-${textColorClass}`;
    const style = `background-color: #${color}`;
    return hyperHTML`<a
    class="${cssClasses}"
    style="${style}"
    href="${href}">${name}</a>`;
  }

  async function processResponse(response, issueNumber) {
    // "message" is always error message from GitHub
    const issue = { title: "", number: issueNumber, state: "", message: "" };
    try {
      const json = await response.json();
      Object.assign(issue, json);
    } catch (err) {
      issue.message = `Error JSON parsing issue #${issueNumber} from GitHub.`;
    }
    if (!response.ok || issue.message) {
      const msg = `Error fetching issue #${issueNumber} from GitHub. ${issue.message} (HTTP Status ${response.status}).`;
      (0, _pubsubhub.pub)("error", msg);
    }
    return [issueNumber, issue];
  }

  async function run(conf) {
    const issuesAndNotes = document.querySelectorAll(".issue, .note, .warning, .ednote");
    if (!issuesAndNotes.length) {
      return; // nothing to do.
    }
    const ghIssues = conf.githubAPI ? await fetchAndStoreGithubIssues(conf) : new Map();
    const { head: headElem } = document;
    headElem.insertBefore(hyperHTML`<style>${[_issuesNotes2.default]}</style>`, headElem.querySelector("link"));
    handleIssues(issuesAndNotes, ghIssues, conf);
  }
});
//# sourceMappingURL=issues-notes.js.map